summaryrefslogtreecommitdiffstats
path: root/kmail/kmmainwidget.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:50:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:50:21 -0600
commit3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12 (patch)
tree89de88213bd261e4ccaade899ab2d6ec34b3a5a7 /kmail/kmmainwidget.cpp
parent1dad5f662a09dfc5cc041caffe0f674044a4dcec (diff)
downloadtdepim-3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.tar.gz
tdepim-3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kmail/kmmainwidget.cpp')
-rw-r--r--kmail/kmmainwidget.cpp114
1 files changed, 57 insertions, 57 deletions
diff --git a/kmail/kmmainwidget.cpp b/kmail/kmmainwidget.cpp
index 1dc08d05..13737d5b 100644
--- a/kmail/kmmainwidget.cpp
+++ b/kmail/kmmainwidget.cpp
@@ -14,14 +14,14 @@
#undef Unsorted // X headers...
#include <tqaccel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqhbox.h>
#include <tqvbox.h>
#include <tqpopupmenu.h>
#include <tqptrlist.h>
#include <tqsignalmapper.h>
#include <tqvaluevector.h>
-#include <tqstylesheet.h>
+#include <stylesheet.h>
#include <kopenwith.h>
#include <kmessagebox.h>
@@ -238,7 +238,7 @@ KMMainWidget::KMMainWidget(TQWidget *parent, const char *name,
this, TQT_SLOT(slotFolderRemoved(KMFolder*)));
connect( kmkernel, TQT_SIGNAL( onlineStatusChanged( GlobalSettings::EnumNetworkState::type ) ),
- this, TQT_SLOT( slotUpdateOnlinetqStatus( GlobalSettings::EnumNetworkState::type ) ) );
+ this, TQT_SLOT( slotUpdateOnlineStatus( GlobalSettings::EnumNetworkState::type ) ) );
toggleSystemTray();
@@ -246,7 +246,7 @@ KMMainWidget::KMMainWidget(TQWidget *parent, const char *name,
mStartupDone = true;
- KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
+ KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
KStatusBar *sb = mainWin ? mainWin->statusBar() : 0;
mVacationScriptIndicator = new KStatusBarLabel( TQString(), 0, sb );
mVacationScriptIndicator->hide();
@@ -287,13 +287,13 @@ void KMMainWidget::destruct()
//-----------------------------------------------------------------------------
void KMMainWidget::readPreConfig(void)
{
- const KConfigGroup tqgeometry( KMKernel::config(), "Geometry" );
+ const KConfigGroup geometry( KMKernel::config(), "Geometry" );
const KConfigGroup reader( KMKernel::config(), "Reader" );
- mLongFolderList = tqgeometry.readEntry( "FolderList", "long" ) != "short";
- mReaderWindowActive = tqgeometry.readEntry( "readerWindowMode", "below" ) != "hide";
- mReaderWindowBelow = tqgeometry.readEntry( "readerWindowMode", "below" ) == "below";
- mThreadPref = tqgeometry.readBoolEntry( "nestedMessages", false );
+ mLongFolderList = geometry.readEntry( "FolderList", "long" ) != "short";
+ mReaderWindowActive = geometry.readEntry( "readerWindowMode", "below" ) != "hide";
+ mReaderWindowBelow = geometry.readEntry( "readerWindowMode", "below" ) == "below";
+ mThreadPref = geometry.readBoolEntry( "nestedMessages", false );
mHtmlPref = reader.readBoolEntry( "htmlMail", false );
mHtmlLoadExtPref = reader.readBoolEntry( "htmlLoadExternal", false );
@@ -516,7 +516,7 @@ void KMMainWidget::writeConfig(void)
{
TQString s;
KConfig *config = KMKernel::config();
- KConfigGroup tqgeometry( config, "Geometry" );
+ KConfigGroup geometry( config, "Geometry" );
if (mMsgView)
mMsgView->writeConfig();
@@ -527,31 +527,31 @@ void KMMainWidget::writeConfig(void)
if ( mFavoriteFolderView )
mFavoriteFolderView->writeConfig();
- tqgeometry.writeEntry( "MainWin", this->tqgeometry().size() );
+ geometry.writeEntry( "MainWin", this->geometry().size() );
const TQValueList<int> widths = ( mLongFolderList ? mPanner1 : mPanner2 )->sizes();
const TQValueList<int> heights = ( mLongFolderList ? mPanner2 : mPanner1 )->sizes();
- tqgeometry.writeEntry( "FolderPaneWidth", widths[0] );
- tqgeometry.writeEntry( "HeaderPaneWidth", widths[1] );
+ geometry.writeEntry( "FolderPaneWidth", widths[0] );
+ geometry.writeEntry( "HeaderPaneWidth", widths[1] );
// Only save when the widget is shown (to avoid saving a wrong value)
if ( mSearchAndHeaders && mSearchAndHeaders->isShown() ) {
- tqgeometry.writeEntry( "HeaderPaneHeight", heights[0] );
- tqgeometry.writeEntry( "ReaderPaneHeight", heights[1] );
+ geometry.writeEntry( "HeaderPaneHeight", heights[0] );
+ geometry.writeEntry( "ReaderPaneHeight", heights[1] );
}
// save the state of the unread/total-columns
- tqgeometry.writeEntry( "UnreadColumn", mFolderTree->unreadIndex() );
- tqgeometry.writeEntry( "TotalColumn", mFolderTree->totalIndex() );
- tqgeometry.writeEntry( "SizeColumn", mFolderTree->sizeIndex() );
+ geometry.writeEntry( "UnreadColumn", mFolderTree->unreadIndex() );
+ geometry.writeEntry( "TotalColumn", mFolderTree->totalIndex() );
+ geometry.writeEntry( "SizeColumn", mFolderTree->sizeIndex() );
}
//-----------------------------------------------------------------------------
void KMMainWidget::createWidgets(void)
{
- // Create the splitters according to the tqlayout settings
+ // Create the splitters according to the layout settings
TQWidget *headerParent = 0,
*mimeParent = 0, *messageParent = 0;
@@ -587,7 +587,7 @@ void KMMainWidget::createWidgets(void)
mTopLayout->add( mPanner1 );
// BUG -sanders these accelerators stop working after switching
- // between long/short folder tqlayout
+ // between long/short folder layout
// Probably need to disconnect them first.
// create list of messages
@@ -950,7 +950,7 @@ void KMMainWidget::slotMailChecked( bool newMail, bool sendOnCheck,
summary += "<br>" + i18n( "1 new message in %1",
"%n new messages in %1",
newInFolder.find( *it ).data() )
- .tqarg( folder->prettyURL() );
+ .arg( folder->prettyURL() );
}
}
}
@@ -965,7 +965,7 @@ void KMMainWidget::slotMailChecked( bool newMail, bool sendOnCheck,
if ( GlobalSettings::self()->verboseNewMailNotification() ) {
summary = i18n( "%1 is a list of the number of new messages per folder",
"<b>New mail arrived</b><br>%1" )
- .tqarg( summary );
+ .arg( summary );
}
else {
summary = i18n( "New mail arrived" );
@@ -973,11 +973,11 @@ void KMMainWidget::slotMailChecked( bool newMail, bool sendOnCheck,
if(kmkernel->xmlGuiInstance()) {
KNotifyClient::Instance instance(kmkernel->xmlGuiInstance());
- KNotifyClient::event( tqtopLevelWidget()->winId(), "new-mail-arrived",
+ KNotifyClient::event( topLevelWidget()->winId(), "new-mail-arrived",
summary );
}
else
- KNotifyClient::event( tqtopLevelWidget()->winId(), "new-mail-arrived",
+ KNotifyClient::event( topLevelWidget()->winId(), "new-mail-arrived",
summary );
if (mBeepOnNew) {
@@ -1097,7 +1097,7 @@ void KMMainWidget::modifyFolder( KMFolderTreeItem* folderItem )
KMFolder* folder = folderItem->folder();
KMFolderTree* folderTree = static_cast<KMFolderTree *>( folderItem->listView() );
KMFolderDialog props( folder, folder->parent(), folderTree,
- i18n("Properties of Folder %1").tqarg( folder->label() ) );
+ i18n("Properties of Folder %1").arg( folder->label() ) );
props.exec();
updateFolderMenu();
//Kolab issue 2152
@@ -1129,7 +1129,7 @@ void KMMainWidget::slotExpireFolder()
KConfigGroupSaver saver(config, "General");
if (config->readBoolEntry("warn-before-expire", true)) {
- str = i18n("<qt>Are you sure you want to expire the folder <b>%1</b>?</qt>").tqarg(TQStyleSheet::escape( mFolder->label() ));
+ str = i18n("<qt>Are you sure you want to expire the folder <b>%1</b>?</qt>").arg(TQStyleSheet::escape( mFolder->label() ));
if (KMessageBox::warningContinueCancel(this, str, i18n("Expire Folder"),
i18n("&Expire"))
!= KMessageBox::Continue) return;
@@ -1152,7 +1152,7 @@ void KMMainWidget::slotEmptyFolder()
TQString text = (isTrash) ?
i18n("Are you sure you want to empty the trash folder?") :
i18n("<qt>Are you sure you want to move all messages from "
- "folder <b>%1</b> to the trash?</qt>").tqarg( TQStyleSheet::escape( mFolder->label() ) );
+ "folder <b>%1</b> to the trash?</qt>").arg( TQStyleSheet::escape( mFolder->label() ) );
if (KMessageBox::warningContinueCancel(this, text, title, KGuiItem( title, "edittrash"))
!= KMessageBox::Continue) return;
@@ -1209,14 +1209,14 @@ void KMMainWidget::slotRemoveFolder()
title = i18n("Delete Search");
str = i18n("<qt>Are you sure you want to delete the search <b>%1</b>?<br>"
"Any messages it shows will still be available in their original folder.</qt>")
- .tqarg( TQStyleSheet::escape( mFolder->label() ) );
+ .arg( TQStyleSheet::escape( mFolder->label() ) );
} else {
title = i18n("Delete Folder");
if ( mFolder->count() == 0 ) {
if ( !mFolder->child() || mFolder->child()->isEmpty() ) {
str = i18n("<qt>Are you sure you want to delete the empty folder "
"<b>%1</b>?</qt>")
- .tqarg( TQStyleSheet::escape( mFolder->label() ) );
+ .arg( TQStyleSheet::escape( mFolder->label() ) );
}
else {
str = i18n("<qt>Are you sure you want to delete the empty folder "
@@ -1224,7 +1224,7 @@ void KMMainWidget::slotRemoveFolder()
"not be empty and their contents will be discarded as well. "
"<p><b>Beware</b> that discarded messages are not saved "
"into your Trash folder and are permanently deleted.</qt>")
- .tqarg( TQStyleSheet::escape( mFolder->label() ) );
+ .arg( TQStyleSheet::escape( mFolder->label() ) );
}
} else {
if ( !mFolder->child() || mFolder->child()->isEmpty() ) {
@@ -1232,14 +1232,14 @@ void KMMainWidget::slotRemoveFolder()
"<b>%1</b>, discarding its contents? "
"<p><b>Beware</b> that discarded messages are not saved "
"into your Trash folder and are permanently deleted.</qt>")
- .tqarg( TQStyleSheet::escape( mFolder->label() ) );
+ .arg( TQStyleSheet::escape( mFolder->label() ) );
}
else {
str = i18n("<qt>Are you sure you want to delete the folder <b>%1</b> "
"and all its subfolders, discarding their contents? "
"<p><b>Beware</b> that discarded messages are not saved "
"into your Trash folder and are permanently deleted.</qt>")
- .tqarg( TQStyleSheet::escape( mFolder->label() ) );
+ .arg( TQStyleSheet::escape( mFolder->label() ) );
}
}
}
@@ -1636,7 +1636,7 @@ void KMMainWidget::updateListFilterAction()
mListFilterAction->setEnabled( false );
else {
mListFilterAction->setEnabled( true );
- mListFilterAction->setText( i18n( "Filter on Mailing-List %1..." ).tqarg( lname ) );
+ mListFilterAction->setText( i18n( "Filter on Mailing-List %1..." ).arg( lname ) );
}
}
@@ -1713,12 +1713,12 @@ void KMMainWidget::slotApplyFilters()
//-----------------------------------------------------------------------------
void KMMainWidget::slotCheckVacation()
{
- updateVactionScriptqStatus( false );
+ updateVactionScripStatus( false );
if ( !kmkernel->askToGoOnline() )
return;
Vacation *vac = new Vacation( TQT_TQOBJECT(this), true /* check only */ );
- connect( vac, TQT_SIGNAL(scriptActive(bool)), TQT_SLOT(updateVactionScriptqStatus(bool)) );
+ connect( vac, TQT_SIGNAL(scriptActive(bool)), TQT_SLOT(updateVactionScripStatus(bool)) );
}
void KMMainWidget::slotEditVacation()
@@ -1731,7 +1731,7 @@ void KMMainWidget::slotEditVacation()
return;
mVacation = new Vacation( TQT_TQOBJECT(this) );
- connect( mVacation, TQT_SIGNAL(scriptActive(bool)), TQT_SLOT(updateVactionScriptqStatus(bool)) );
+ connect( mVacation, TQT_SIGNAL(scriptActive(bool)), TQT_SLOT(updateVactionScripStatus(bool)) );
if ( mVacation->isUsable() ) {
connect( mVacation, TQT_SIGNAL(result(bool)), mVacation, TQT_SLOT(deleteLater()) );
} else {
@@ -1903,10 +1903,10 @@ void KMMainWidget::slotSaveAttachments()
saveCommand->start();
}
-void KMMainWidget::slotOnlinetqStatus()
+void KMMainWidget::slotOnlineStatus()
{
// KMKernel will emit a signal when we toggle the network state that is caught by
// KMMainWidget::slotUpdateOnlinetqStatus to update our GUI
if ( GlobalSettings::self()->networkState() == GlobalSettings::EnumNetworkState::Online ) {
// if online; then toggle and set it offline.
kmkernel->stopNetworkJobs();
@@ -1916,7 +1916,7 @@ void KMMainWidget::slotOnlinetqStatus()
}
}
-void KMMainWidget::slotUpdateOnlinetqStatus( GlobalSettings::EnumNetworkState::type )
+void KMMainWidget::slotUpdateOnlineStatus( GlobalSettings::EnumNetworkState::type )
{
if ( GlobalSettings::self()->networkState() == GlobalSettings::EnumNetworkState::Online )
actionCollection()->action( "online_status" )->setText( i18n("Work Offline") );
@@ -2239,37 +2239,37 @@ void KMMainWidget::slotReplaceMsgByUnencryptedVersion()
//-----------------------------------------------------------------------------
void KMMainWidget::slotSetThreadStatusNew()
{
- mHeaders->setThreadtqStatus(KMMsgStatusNew);
+ mHeaders->setThreadStatus(KMMsgStatusNew);
}
//-----------------------------------------------------------------------------
void KMMainWidget::slotSetThreadStatusUnread()
{
- mHeaders->setThreadtqStatus(KMMsgStatusUnread);
+ mHeaders->setThreadStatus(KMMsgStatusUnread);
}
//-----------------------------------------------------------------------------
void KMMainWidget::slotSetThreadStatusFlag()
{
- mHeaders->setThreadtqStatus(KMMsgStatusFlag, true);
+ mHeaders->setThreadStatus(KMMsgStatusFlag, true);
}
//-----------------------------------------------------------------------------
void KMMainWidget::slotSetThreadStatusRead()
{
- mHeaders->setThreadtqStatus(KMMsgStatusRead);
+ mHeaders->setThreadStatus(KMMsgStatusRead);
}
//-----------------------------------------------------------------------------
void KMMainWidget::slotSetThreadStatusTodo()
{
- mHeaders->setThreadtqStatus(KMMsgStatusTodo, true);
+ mHeaders->setThreadStatus(KMMsgStatusTodo, true);
}
//-----------------------------------------------------------------------------
void KMMainWidget::slotSetThreadStatusWatched()
{
- mHeaders->setThreadtqStatus(KMMsgStatusWatched, true);
+ mHeaders->setThreadStatus(KMMsgStatusWatched, true);
if (mWatchThreadAction->isChecked()) {
mIgnoreThreadAction->setChecked(false);
}
@@ -2278,7 +2278,7 @@ void KMMainWidget::slotSetThreadStatusWatched()
//-----------------------------------------------------------------------------
void KMMainWidget::slotSetThreadStatusIgnored()
{
- mHeaders->setThreadtqStatus(KMMsgStatusIgnored, true);
+ mHeaders->setThreadStatus(KMMsgStatusIgnored, true);
if (mIgnoreThreadAction->isChecked()) {
mWatchThreadAction->setChecked(false);
}
@@ -2690,7 +2690,7 @@ void KMMainWidget::setupActions()
TQT_SLOT(slotSendQueued()), actionCollection(), "send_queued");
(void) new KAction( i18n("Online Status (unknown)"), "online_status", 0, TQT_TQOBJECT(this),
- TQT_SLOT(slotOnlinetqStatus()), actionCollection(), "online_status");
+ TQT_SLOT(slotOnlineStatus()), actionCollection(), "online_status");
KActionMenu *sendActionMenu = new
KActionMenu( i18n("Send Queued Messages Via"), "mail_send_via", actionCollection(),
@@ -3402,7 +3402,7 @@ void KMMainWidget::updateMessageActions()
actionCollection()->action( "go_prev_unread_message" )->setEnabled( enable_goto_unread );
actionCollection()->action( "send_queued" )->setEnabled( kmkernel->outboxFolder()->count() > 0 );
actionCollection()->action( "send_queued_via" )->setEnabled( kmkernel->outboxFolder()->count() > 0 );
- slotUpdateOnlinetqStatus( static_cast<GlobalSettingsBase::EnumNetworkState::type>( GlobalSettings::self()->networkState() ) );
+ slotUpdateOnlineStatus( static_cast<GlobalSettingsBase::EnumNetworkState::type>( GlobalSettings::self()->networkState() ) );
if (action( "edit_undo" ))
action( "edit_undo" )->setEnabled( mHeaders->canUndo() );
@@ -3514,8 +3514,8 @@ void KMMainWidget::slotMemInfo() {
"Memory allocated, not used: %3\n"
"Memory total allocated : %4\n"
"Max. freeable memory : %5\n")
- .tqarg(mi.hblks).tqarg(fmt(mi.uordblks)).tqarg(fmt(mi.fordblks))
- .tqarg(fmt(mi.arena)).tqarg(fmt(mi.keepcost));
+ .arg(mi.hblks).arg(fmt(mi.uordblks)).arg(fmt(mi.fordblks))
+ .arg(fmt(mi.arena)).arg(fmt(mi.keepcost));
KMessageBox::information(0, s, "Malloc information", s);
#endif
}
@@ -3712,13 +3712,13 @@ void KMMainWidget::initializeFilterActions()
TQValueListConstIterator<KMFilter*> it = kmkernel->filterMgr()->filters().constBegin();
for ( ;it != kmkernel->filterMgr()->filters().constEnd(); ++it ) {
if (!(*it)->isEmpty() && (*it)->configureShortcut()) {
- filterName = TQString("Filter %1").tqarg((*it)->name());
+ filterName = TQString("Filter %1").arg((*it)->name());
normalizedName = filterName.replace(" ", "_");
if (action(normalizedName.utf8()))
continue;
filterCommand = new KMMetaFilterActionCommand(*it, mHeaders, this);
mFilterCommands.append(filterCommand);
- TQString as = i18n("Filter %1").tqarg((*it)->name());
+ TQString as = i18n("Filter %1").arg((*it)->name());
TQString icon = (*it)->icon();
if ( icon.isEmpty() )
icon = "gear";
@@ -3801,8 +3801,8 @@ void KMMainWidget::slotShortcutChanged( KMFolder *folder )
FolderShortcutCommand *c = new FolderShortcutCommand( this, folder );
mFolderShortcutCommands.insert( folder->idString(), c );
- TQString actionlabel = TQString( "FolderShortcut %1").tqarg( folder->prettyURL() );
- TQString actionname = TQString( "FolderShortcut %1").tqarg( folder->idString() );
+ TQString actionlabel = TQString( "FolderShortcut %1").arg( folder->prettyURL() );
+ TQString actionname = TQString( "FolderShortcut %1").arg( folder->idString() );
TQString normalizedName = actionname.replace(" ", "_");
KAction* action =
new KAction(actionlabel, folder->shortcut(), c, TQT_SLOT(start()),
@@ -3993,14 +3993,14 @@ void KMMainWidget::slotRequestFullSearchFromQuickSearch()
assert( mSearchWin );
KMSearchPattern pattern;
pattern.append( KMSearchRule::createInstance( "<message>", KMSearchRule::FuncContains, mQuickSearchLine->currentSearchTerm() ) );
- int status = mQuickSearchLine->currentqStatus();
+ int status = mQuickSearchLine->currenStatus();
if ( status != 0 ) {
- pattern.append( new KMSearchRuletqStatus( status ) );
+ pattern.append( new KMSearchRuleStatus( status ) );
}
mSearchWin->setSearchPattern( pattern );
}
-void KMMainWidget::updateVactionScriptqStatus(bool active)
+void KMMainWidget::updateVactionScripStatus(bool active)
{
mVacationIndicatorActive = active;
if ( active ) {
@@ -1903,10 +1903,10 @@ void KMMainWidget::slotSaveAttachments()
{
// KMKernel will emit a signal when we toggle the network state that is caught by
- // KMMainWidget::slotUpdateOnlinetqStatus to update our GUI
+ // KMMainWidget::slotUpdateOnlineStatus to update our GUI
if ( GlobalSettings::self()->networkState() == GlobalSettings::EnumNetworkState::Online ) {
// if online; then toggle and set it offline.